# from utils import parseArgs
# from config import get_config, set_config
# from trickle import shell2Trickle
from .utils import parseArgs
from .config import get_config, set_config
from .trickle import shell2Trickle

    
def main():
    args = parseArgs()
    if args["endpoint"] and args["token"]:
        set_config(args["endpoint"], args["token"])

    conf = get_config()
    # print(conf)
    if not conf:
        raise Exception("config is None, first set your config by running "\
            "'trickle send -e [endpoint] -t [token]'")
    
    send_args_list = args["send"]
    send_args_list.pop(0)
    if send_args_list:
        content = send_args_list[0]
        endpoint = conf.get("endpoint")
        token = conf.get("token")
        shell2Trickle(content, endpoint, token)


if __name__ == "__main__":
    main()


import argparse
from uuid import uuid4


def parseArgs():
    # 获取脚本参数
    ap = argparse.ArgumentParser(
        prog="trickle",
        description="Post your trickle by shell"
    )
    ap.add_argument("send", type=str, nargs="+", help="your trickle content")
    ap.add_argument("-e", "--endpoint", type=str, default="", help="trickle intg endpoint")
    ap.add_argument("-t", "--token", type=str, default='', help="your trickle account token")

    args = vars(ap.parse_args())
    return args


def get_uuid():
    return str(uuid4())


from setuptools import setup, find_packages


long_description = 'Script for Trickle'

setup(
    name ='shell_trickle',
    version ='1.0.5',
    author ='Lania Kea',
    author_email ='lania.dang@visionwx.com',
    url ='',
    description ='Demo Package for Shell Trickle.',
    long_description = long_description,
    long_description_content_type ="text/markdown",
    license ='MIT',
    packages = find_packages(),
    entry_points ={
        'console_scripts': [
            'trickle = src.main:main'
        ]
    },
    classifiers =(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
    keywords ='shell trickle',
    install_requires = [
        "requests"
    ],
    zip_safe = False
)


from pathlib import Path
from configparser import ConfigParser


config_path = Path.joinpath(Path.home(), ".shell_trickle.ini")
if not Path.exists(config_path):
    open(config_path, "a").close()


def set_config(endpoint: str, app_member_token: str):
    lines = [
        "[DEFAULT]\n",
        f"endpoint = {endpoint}\n",
        f"token = {app_member_token}\n"
    ]
    with open(config_path, "w") as f:
        f.writelines(lines)


config_parser = ConfigParser()
def get_config():
    if not Path.exists(config_path):
        print("please set config first...")
        return None

    config_parser.read(config_path)
    return config_parser.defaults()



# from utils import get_uuid
from .utils import get_uuid
import requests


class TrickleSendFailed(Exception):
    pass


def generateBlock(text: str):
    return {
        "id": get_uuid(),
        "type": "rich_texts",
        "blocks": [],
        "indent": 0,
        "display": "block",
        "isFirst": True,
        "elements": [{
            "id": get_uuid(),
            "text": text,
            "type": "text",
            "elements": [],
            "isCurrent": True
        }],
        "isCurrent": False
    }


def newline():
    return generateBlock(text="")


def content2Blocks(content: str):
    blocks = []

    paragraphs = content.split("\\n")
    for idx, para in enumerate(paragraphs):
        blocks.append(generateBlock(text=para.strip()))
        if idx != len(paragraphs)-1:
            blocks.append(newline())

    return blocks


def shell2Trickle(content: str, endpoint: str, token: str):
    blocks = content2Blocks(content)
    resp = requests.post(
        url=endpoint, 
        json={"blocks": blocks}, 
        headers={"Authorization": token}
    )

    if resp.status_code != 201:
        raise TrickleSendFailed("Something wrong, Your trickle send failed!")
    
    print("Sended Successfully!")


if __name__ == "__main__":
    content = "hello world \\n   123123"

    blocks = content2Blocks(content)
    print(blocks)